=== modified file 'lib/lp/bugs/browser/bugtask.py'
--- lib/lp/bugs/browser/bugtask.py	2011-12-04 03:58:11 +0000
+++ lib/lp/bugs/browser/bugtask.py	2011-12-04 23:02:05 +0000
@@ -2524,7 +2524,7 @@
     custom_widget('assignee', PersonPickerWidget)
     custom_widget('bug_reporter', PersonPickerWidget)
     custom_widget('bug_commenter', PersonPickerWidget)
-    custom_widget('bug_supervisor', PersonPickerWidget)
+    custom_widget('structural_subscriber', PersonPickerWidget)
     custom_widget('subscriber', PersonPickerWidget)
 
     @cachedproperty
@@ -3049,11 +3049,12 @@
             IDistroSeries.providedBy(context) or
             ISourcePackage.providedBy(context))
 
-    def shouldShowSupervisorWidget(self):
-        """
-        Should the bug supervisor widget be shown on the advanced search page?
-        """
-        return True
+    def shouldShowStructuralSubscriberWidget(self):
+        """Should the structural subscriber widget be shown on the page?
+
+        Show the widget when there are subordinate structures.
+        """
+        return self.structural_subscriber_label is not None
 
     def shouldShowNoPackageWidget(self):
         """Should the widget to filter on bugs with no package be shown?
@@ -3096,6 +3097,21 @@
         """Should the User's Teams portlet me shown in the results?"""
         return False
 
+    @property
+    def structural_subscriber_label(self):
+        if IDistribution.providedBy(self.context):
+            return 'Package, or series subscriber'
+        elif IDistroSeries.providedBy(self.context):
+            return 'Package subscriber'
+        elif IProduct.providedBy(self.context):
+            return 'Series subscriber'
+        elif IProjectGroup.providedBy(self.context):
+            return 'Project or series subscriber'
+        elif IPerson.providedBy(self.context):
+            return 'Project, distribution, package, or series subscriber'
+        else:
+            return None
+
     def getSortLink(self, colname):
         """Return a link that can be used to sort results by colname."""
         form = self.request.form
@@ -3198,7 +3214,7 @@
         error_message = _(
             "There's no person with the name or email address '%s'.")
 
-        for name in ('assignee', 'bug_reporter', 'bug_supervisor',
+        for name in ('assignee', 'bug_reporter', 'structural_subscriber',
                      'bug_commenter', 'subscriber'):
             if self.getFieldError(name):
                 self.setFieldError(

=== modified file 'lib/lp/bugs/browser/tests/test_bugtask.py'
--- lib/lp/bugs/browser/tests/test_bugtask.py	2011-11-30 16:53:01 +0000
+++ lib/lp/bugs/browser/tests/test_bugtask.py	2011-12-02 21:47:43 +0000
@@ -1436,8 +1436,138 @@
         self.assertTrue(notifications.pop().message.startswith(expected))
 
 
+class TestPersonBugs(TestCaseWithFactory):
+    """Test the bugs overview page for distributions."""
+
+    layer = DatabaseFunctionalLayer
+
+    def setUp(self):
+        super(TestPersonBugs, self).setUp()
+        self.target = self.factory.makePerson()
+
+    def test_shouldShowStructuralSubscriberWidget(self):
+        view = create_initialized_view(
+            self.target, name=u'+bugs', rootsite='bugs')
+        self.assertTrue(view.shouldShowStructuralSubscriberWidget())
+
+    def test_structural_subscriber_label(self):
+        view = create_initialized_view(
+            self.target, name=u'+bugs', rootsite='bugs')
+        self.assertEqual(
+            'Project, distribution, package, or series subscriber',
+            view.structural_subscriber_label)
+
+
+class TestDistributionBugs(TestCaseWithFactory):
+    """Test the bugs overview page for distributions."""
+
+    layer = DatabaseFunctionalLayer
+
+    def setUp(self):
+        super(TestDistributionBugs, self).setUp()
+        self.target = self.factory.makeDistribution()
+
+    def test_shouldShowStructuralSubscriberWidget(self):
+        view = create_initialized_view(
+            self.target, name=u'+bugs', rootsite='bugs')
+        self.assertTrue(view.shouldShowStructuralSubscriberWidget())
+
+    def test_structural_subscriber_label(self):
+        view = create_initialized_view(
+            self.target, name=u'+bugs', rootsite='bugs')
+        self.assertEqual(
+            'Package, or series subscriber', view.structural_subscriber_label)
+
+
+class TestDistroSeriesBugs(TestCaseWithFactory):
+    """Test the bugs overview page for distro series."""
+
+    layer = DatabaseFunctionalLayer
+
+    def setUp(self):
+        super(TestDistroSeriesBugs, self).setUp()
+        self.target = self.factory.makeDistroSeries()
+
+    def test_shouldShowStructuralSubscriberWidget(self):
+        view = create_initialized_view(
+            self.target, name=u'+bugs', rootsite='bugs')
+        self.assertTrue(view.shouldShowStructuralSubscriberWidget())
+
+    def test_structural_subscriber_label(self):
+        view = create_initialized_view(
+            self.target, name=u'+bugs', rootsite='bugs')
+        self.assertEqual(
+            'Package subscriber', view.structural_subscriber_label)
+
+
+class TestDistributionSourcePackageBugs(TestCaseWithFactory):
+    """Test the bugs overview page for distribution source packages."""
+
+    layer = DatabaseFunctionalLayer
+
+    def setUp(self):
+        super(TestDistributionSourcePackageBugs, self).setUp()
+        self.target = self.factory.makeDistributionSourcePackage()
+
+    def test_shouldShowStructuralSubscriberWidget(self):
+        view = create_initialized_view(
+            self.target, name=u'+bugs', rootsite='bugs')
+        self.assertFalse(view.shouldShowStructuralSubscriberWidget())
+
+
+class TestDistroSeriesSourcePackageBugs(TestCaseWithFactory):
+    """Test the bugs overview page for distro series source packages."""
+
+    layer = DatabaseFunctionalLayer
+
+    def setUp(self):
+        super(TestDistroSeriesSourcePackageBugs, self).setUp()
+        self.target = self.factory.makeSourcePackage()
+
+    def test_shouldShowStructuralSubscriberWidget(self):
+        view = create_initialized_view(
+            self.target, name=u'+bugs', rootsite='bugs')
+        self.assertFalse(view.shouldShowStructuralSubscriberWidget())
+
+
+class TestProductBugs(TestCaseWithFactory):
+    """Test the bugs overview page for projects."""
+
+    layer = DatabaseFunctionalLayer
+
+    def setUp(self):
+        super(TestProductBugs, self).setUp()
+        self.target = self.factory.makeProduct()
+
+    def test_shouldShowStructuralSubscriberWidget(self):
+        view = create_initialized_view(
+            self.target, name=u'+bugs', rootsite='bugs')
+        self.assertTrue(view.shouldShowStructuralSubscriberWidget())
+
+    def test_structural_subscriber_label(self):
+        view = create_initialized_view(
+            self.target, name=u'+bugs', rootsite='bugs')
+        self.assertEqual(
+            'Series subscriber', view.structural_subscriber_label)
+
+
+class TestProductSeriesBugs(TestCaseWithFactory):
+    """Test the bugs overview page for project series."""
+
+    layer = DatabaseFunctionalLayer
+
+    def setUp(self):
+        super(TestProductSeriesBugs, self).setUp()
+        self.target = self.factory.makeProductSeries()
+
+    def test_shouldShowStructuralSubscriberWidget(self):
+        view = create_initialized_view(
+            self.target, name=u'+bugs', rootsite='bugs')
+        self.assertFalse(view.shouldShowStructuralSubscriberWidget())
+
+
 class TestProjectGroupBugs(TestCaseWithFactory):
-    """Test the bugs overview page for Project Groups."""
+    """Test the bugs overview page for project groups."""
 
     layer = DatabaseFunctionalLayer
 
@@ -1534,6 +1664,17 @@
         help_link = find_tag_by_id(contents, 'getting-started-help')
         self.assertIs(None, help_link)
 
+    def test_shouldShowStructuralSubscriberWidget(self):
+        view = create_initialized_view(
+            self.projectgroup, name=u'+bugs', rootsite='bugs')
+        self.assertTrue(view.shouldShowStructuralSubscriberWidget())
+
+    def test_structural_subscriber_label(self):
+        view = create_initialized_view(
+            self.projectgroup, name=u'+bugs', rootsite='bugs')
+        self.assertEqual(
+            'Project or series subscriber', view.structural_subscriber_label)
+
 
 class TestBugActivityItem(TestCaseWithFactory):
 

=== modified file 'lib/lp/bugs/interfaces/bugtask.py'
--- lib/lp/bugs/interfaces/bugtask.py	2011-11-18 04:06:16 +0000
+++ lib/lp/bugs/interfaces/bugtask.py	2011-12-02 18:54:15 +0000
@@ -914,7 +914,7 @@
         """
 
     def userHasPrivileges(user):
-        """Is the user a privledged one, allowed to changed details on a 
+        """Is the user a priviledged one, allowed to changed details on a
         bug?.
 
         :return: A boolean.
@@ -1017,10 +1017,11 @@
         required=False)
     has_cve = Bool(
         title=_('Show only bugs associated with a CVE'), required=False)
-    bug_supervisor = Choice(
-        title=_('Bug supervisor'), vocabulary='ValidPersonOrTeam',
-        description=_('Show only bugs in packages this person or team '
-                      'is subscribed to.'),
+    structural_subscriber = Choice(
+        title=_('Structural Subscriber'), vocabulary='ValidPersonOrTeam',
+        description=_(
+            'Show only bugs in projects, series, distributions, and packages '
+            'that this person or team is subscribed to.'),
         required=False)
     bug_commenter = Choice(
         title=_('Bug commenter'), vocabulary='ValidPersonOrTeam',

=== modified file 'lib/lp/bugs/stories/bugs/xx-bugs-advanced-search-upstream-status.txt'
--- lib/lp/bugs/stories/bugs/xx-bugs-advanced-search-upstream-status.txt	2011-06-28 15:04:29 +0000
+++ lib/lp/bugs/stories/bugs/xx-bugs-advanced-search-upstream-status.txt	2011-12-05 16:05:20 +0000
@@ -1,5 +1,5 @@
-The advanced search page provides widgets for filtering bugtasks based on
-upstream status.
+The advanced search page provides widgets for filtering bugtasks based
+on upstream status.
 
 There are currently four bugs open in Ubuntu.
 
@@ -22,10 +22,13 @@
 
     # XXX: Bjorn Tillenius 2006-07-04 bug=51853:
     #      Can't click on the link due to bug 51853.
+
     >>> anon_browser.getLink('Advanced search').attrs['href']
     '?advanced=1'
+
     >>> anon_browser.open('http://launchpad.dev/ubuntu/+bugs?advanced=1')
-    >>> upstream_status = anon_browser.getControl(name='field.status_upstream')
+    >>> upstream_status = anon_browser.getControl(
+    ...     name='field.status_upstream')
     >>> upstream_status.displayValue = [
     ...     'Show bugs that need to be forwarded to an upstream bug tracker']
     >>> anon_browser.getControl('Search', index=0).click()
@@ -59,10 +62,12 @@
     Ubuntu Hoary, New
     mozilla-firefox (Debian), Invalid
     mozilla-firefox (Debian Woody), Invalid
+
     >>> logout()
 
     >>> anon_browser.open('http://launchpad.dev/ubuntu/+bugs?advanced=1')
-    >>> upstream_status = anon_browser.getControl(name='field.status_upstream')
+    >>> upstream_status = anon_browser.getControl(
+    ...     name='field.status_upstream')
     >>> upstream_status.displayValue = [
     ...     'Show bugs that need to be forwarded to an upstream bug tracker']
     >>> anon_browser.getControl('Search', index=0).click()
@@ -76,7 +81,8 @@
 on upstream, to focus instead on things they need to work on.
 
     >>> anon_browser.open('http://launchpad.dev/ubuntu/+bugs?advanced=1')
-    >>> upstream_status = anon_browser.getControl(name='field.status_upstream')
+    >>> upstream_status = anon_browser.getControl(
+    ...     name='field.status_upstream')
     >>> upstream_status.displayValue = [
     ...     'Show bugs that are not known to affect upstream']
     >>> anon_browser.getControl('Search', index=0).click()
@@ -107,7 +113,8 @@
 modified and the sampledata we created above will show up.
 
     >>> anon_browser.open('http://launchpad.dev/ubuntu/+bugs?advanced=1')
-    >>> upstream_status = anon_browser.getControl(name='field.status_upstream')
+    >>> upstream_status = anon_browser.getControl(
+    ...     name='field.status_upstream')
     >>> upstream_status.displayValue = [
     ...     'Show bugs that are resolved upstream']
     >>> anon_browser.getControl('Search', index=0).click()
@@ -119,11 +126,12 @@
     2 Blackhole Trash folder
       &mdash; Medium New
 
-If more than one filter for upstream status is selected, the search returns
-the union of the results for the individual filters.
+If more than one filter for upstream status is selected, the search
+returns the union of the results for the individual filters.
 
     >>> anon_browser.open('http://launchpad.dev/ubuntu/+bugs?advanced=1')
-    >>> upstream_status = anon_browser.getControl(name='field.status_upstream')
+    >>> upstream_status = anon_browser.getControl(
+    ...     name='field.status_upstream')
     >>> upstream_status.displayValue = [
     ...     'Show bugs that are resolved upstream',
     ...     'Show bugs that are not known to affect upstream'
@@ -140,7 +148,9 @@
     2 Blackhole Trash folder
       &mdash; Medium New
 
-== Backward-compatibility for old bookmars ==
+
+Backward-compatibility for old bookmars
+---------------------------------------
 
 Before Launchpad version 1.1.6, users could selected only one upstream
 status. Bookmarks of such searches work nevertheless.
@@ -159,7 +169,7 @@
     ...     'assignee_option': 'any',
     ...     'field.assignee': '',
     ...     'field.bug_reporter': '',
-    ...     'field.bug_supervisor': '',
+    ...     'field.structural_subscriber': '',
     ...     'field.component-empty-marker': '1',
     ...     'field.omit_dupes.used': '',
     ...     'field.omit_dupes': 'on',
@@ -227,9 +237,10 @@
     UnexpectedFormData: Unexpected value for field 'status_upstream'.
     Perhaps your bookmarks are out of date or you changed the URL by hand?
 
-
 Let's reset the statuses we set.
 
     >>> login('test@canonical.com')
     >>> test_helper.tearDownBugsElsewhereTests()
     >>> logout()
+
+

=== modified file 'lib/lp/bugs/stories/bugtask-searches/xx-advanced-people-filters.txt'
--- lib/lp/bugs/stories/bugtask-searches/xx-advanced-people-filters.txt	2011-11-24 23:22:16 +0000
+++ lib/lp/bugs/stories/bugtask-searches/xx-advanced-people-filters.txt	2011-12-05 16:05:20 +0000
@@ -1,9 +1,13 @@
-= Advanced searching using person-based filters =
+Advanced searching using person-based filters
+=============================================
 
 The advanced search form allows us to filter bugs based on the people
-related to them: assignees, commenters, bug supervisors and subscribers.
-
-== Widget basics ==
+related to them: assignees, commenters, package subscribers and
+subscribers.
+
+
+Widget basics
+-------------
 
 When searching by username we need to both select the corresponding
 radio button and enter a valid user name. The username input
@@ -14,11 +18,13 @@
     >>> assignee_widget = find_tag_by_id(browser.contents, 'field.assignee')
     >>> print assignee_widget['onkeypress']
     selectWidget('assignee_option', event)
+
     >>> print find_tag_by_id(browser.contents, 'assignee_option')
     <input...type="radio"...>
 
 
-== Searching by assignee ==
+Searching by assignee
+---------------------
 
 To search bugs by assignee, we can select from two options: `Nobody`
 (bugs that aren't assigned) or by a specific user name.
@@ -28,7 +34,6 @@
 Let's test the advanced form for a distribution.  We get the search
 results when we use a valid assignee.
 
-    >>> # Debian must enable the Launchpad bug tracker to access bugs.
     >>> from lp.testing.service_usage_helpers import set_service_usage
     >>> set_service_usage('debian', bug_tracking_usage='LAUNCHPAD')
 
@@ -38,7 +43,8 @@
     >>> print_bugtasks(anon_browser.contents)
     2 Blackhole Trash folder mozilla-firefox Low Confirmed
 
-    >>> anon_browser.open('http://bugs.launchpad.dev/~name12/+reportedbugs?advanced=1')
+    >>> anon_browser.open(
+    ...     'http://bugs.launchpad.dev/~name12/+reportedbugs?advanced=1')
     >>> anon_browser.getControl(name='field.assignee').value = 'mark'
     >>> anon_browser.getControl('Search', index=0).click()
     >>> print_bugtasks(anon_browser.contents)
@@ -47,19 +53,23 @@
 If we enter an invalid assignee, we'll get a nice error message.
 
     >>> anon_browser.open('http://bugs.launchpad.dev/ubuntu/+bugs?advanced=1')
-    >>> anon_browser.getControl(name='field.assignee').value = 'invalid-assignee'
-    >>> anon_browser.getControl('Search', index=0).click()
-    >>> get_feedback_messages(anon_browser.contents)
-    [u"There's no person with the name or email address 'invalid-assignee'."]
-
-    >>> anon_browser.open('http://bugs.launchpad.dev/~name12/+reportedbugs?advanced=1')
-    >>> anon_browser.getControl(name='field.assignee').value = 'invalid-assignee'
-    >>> anon_browser.getControl('Search', index=0).click()
-    >>> get_feedback_messages(anon_browser.contents)
-    [u"There's no person with the name or email address 'invalid-assignee'."]
-
-
-== Searching by reporter ==
+    >>> anon_browser.getControl(name='field.assignee').value = (
+    ...     'invalid-assignee')
+    >>> anon_browser.getControl('Search', index=0).click()
+    >>> get_feedback_messages(anon_browser.contents)
+    [u"There's no person with the name or email address 'invalid-assignee'."]
+
+    >>> anon_browser.open(
+    ...     'http://bugs.launchpad.dev/~name12/+reportedbugs?advanced=1')
+    >>> anon_browser.getControl(name='field.assignee').value = (
+    ...     'invalid-assignee')
+    >>> anon_browser.getControl('Search', index=0).click()
+    >>> get_feedback_messages(anon_browser.contents)
+    [u"There's no person with the name or email address 'invalid-assignee'."]
+
+
+Searching by reporter
+---------------------
 
 Valid searches work:
 
@@ -74,36 +84,39 @@
     >>> anon_browser.getControl(name='field.bug_reporter').value = 'name12'
     >>> anon_browser.getControl('Search', index=0).click()
     >>> print_bugtasks(anon_browser.contents)
-    5 Firefox install instructions should be complete Mozilla Firefox Critical New
+    5 Firefox ... should be complete Mozilla Firefox Critical New
     2 Blackhole Trash folder mozilla-firefox (Debian) Low Confirmed
 
 and invalid searches don't OOPS:
 
     >>> anon_browser.open('http://bugs.launchpad.dev/debian/+bugs?advanced=1')
-    >>> anon_browser.getControl(name='field.bug_reporter').value = 'invalid-reporter'
+    >>> anon_browser.getControl(name='field.bug_reporter').value = (
+    ...     'invalid-reporter')
     >>> anon_browser.getControl('Search', index=0).click()
     >>> get_feedback_messages(anon_browser.contents)
     [u"There's no person with the name or email address 'invalid-reporter'."]
 
     >>> anon_browser.open('http://bugs.launchpad.dev/~name12/+assignedbugs')
-    >>> anon_browser.getControl(name='field.bug_reporter').value = 'invalid-reporter'
+    >>> anon_browser.getControl(name='field.bug_reporter').value = (
+    ...     'invalid-reporter')
     >>> anon_browser.getControl('Search', index=0).click()
     >>> get_feedback_messages(anon_browser.contents)
     [u"There's no person with the name or email address 'invalid-reporter'."]
 
 
-== Searching for a bug commenter's bugs ==
+Searching for a bug commenter's bugs
+------------------------------------
 
 On the advanced search there's a field for specifying a bug commenter.
 
     >>> anon_browser.open('http://bugs.launchpad.dev/ubuntu/+bugs?advanced=1')
-    >>> anon_browser.getControl('Bug commenter') is not None
+    >>> anon_browser.getControl('Commenter') is not None
     True
 
 If an non-existent person is entered there, an error message is
 displayed.
 
-    >>> anon_browser.getControl('Bug commenter').value = 'non-existent'
+    >>> anon_browser.getControl('Commenter').value = 'non-existent'
     >>> anon_browser.getControl('Search', index=0).click()
     >>> for message in find_tags_by_class(anon_browser.contents, 'message'):
     ...     print message.renderContents()
@@ -111,7 +124,7 @@
 
 Entering an existing person shows all bugs that person has commented on.
 
-    >>> anon_browser.getControl('Bug commenter').value = 'foo.bar@canonical.com'
+    >>> anon_browser.getControl('Commenter').value = 'foo.bar@canonical.com'
     >>> anon_browser.getControl('Search', index=0).click()
 
     >>> from lp.bugs.tests.bug import print_bugtasks
@@ -120,29 +133,24 @@
       linux-source-2.6.15 Medium New
 
 
-== Searching for a bug supervisor's bugs ==
+Searching for a package subscriber's bugs
+-----------------------------------------
 
-On the advanced search there's a field for specifying a bug supervisor.
+On the advanced search there's a field for specifying a project,
+distribution, package, or series subscriber.
 
     >>> anon_browser.open('http://bugs.launchpad.dev/ubuntu/+bugs?advanced=1')
-    >>> anon_browser.getControl('Bug supervisor') is not None
+    >>> anon_browser.getControl('Package, or series subscriber') is not None
     True
 
-If an non-existent person is entered there, an error message is
-displayed.
-
-    >>> anon_browser.getControl('Bug supervisor').value = 'non-existent'
-    >>> anon_browser.getControl('Search', index=0).click()
-    >>> for message in find_tags_by_class(anon_browser.contents, 'message'):
-    ...     print message.renderContents()
-    There's no person with the name or email address 'non-existent'.
-
-Entering an existing person shows all bugs for packages or products that the
-person is a bug supervisor for. Since we're in the ubuntu context, only bugs
-for Ubuntu packages will be returned. In Ubuntu, Foo Bar is a bug supervisor
-for mozilla-firefox and pmount, but there aren't any bugs open for pmount.
-
-    >>> anon_browser.getControl('Bug supervisor').value = 'foo.bar@canonical.com'
+Entering an existing person shows all bugs for packages or products that
+the person is a package subscriber for. Since we're in the ubuntu
+context, only bugs for Ubuntu packages will be returned. In Ubuntu, Foo
+Bar is a package subscriber for mozilla-firefox and pmount, but there
+aren't any bugs open for pmount.
+
+    >>> anon_browser.getControl(
+    ...     'Package, or series subscriber').value = 'foo.bar@canonical.com'
     >>> anon_browser.getControl('Search', index=0).click()
 
     >>> from lp.bugs.tests.bug import print_bugtasks
@@ -151,42 +159,47 @@
       mozilla-firefox Medium New
 
 
-= Searching for a bug subscriber's bugs =
+Searching for a bug subscriber's bugs
+=====================================
 
-On the advanced search page there's a field for specifying a bug subscriber:
+On the advanced search page there's a field for specifying a bug
+subscriber:
 
     >>> search_url = 'http://bugs.launchpad.dev/firefox/+bugs?advanced=1'
     >>> anon_browser.open(search_url)
-    >>> anon_browser.getControl('Bug subscriber') is not None
+    >>> anon_browser.getControl('Subscriber') is not None
     True
 
-If an non-existent person is entered there, an error message is displayed:
+If an non-existent person is entered there, an error message is
+displayed:
 
-    >>> anon_browser.getControl('Bug subscriber').value = 'non-existent'
+    >>> anon_browser.getControl('Subscriber').value = 'non-existent'
     >>> anon_browser.getControl('Search', index=0).click()
     >>> for message in find_tags_by_class(anon_browser.contents, 'message'):
     ...     print message.renderContents()
     There's no person with the name or email address 'non-existent'.
 
-Entering an existing person shows all bugs for packages or products that the
-person is subscribed to. To demonstrate, we'll begin with a user who isn't
-subscribed to any bugs. In this case, no bugs are found:
+Entering an existing person shows all bugs for packages or products that
+the person is subscribed to. To demonstrate, we'll begin with a user who
+isn't subscribed to any bugs. In this case, no bugs are found:
 
     >>> subscriber = 'no-priv@canonical.com'
-    >>> anon_browser.getControl('Bug subscriber').value = subscriber
+    >>> anon_browser.getControl('Subscriber').value = subscriber
     >>> anon_browser.getControl('Search', index=0).click()
     >>> print extract_text(find_main_content(anon_browser.contents))
     Bugs : Mozilla Firefox ...
     No results for search
 
-We'll continue by subscribing the same user to a couple of bugs. However,
-first we'll register a couple of bugs for the Mozilla Firefox product:
+We'll continue by subscribing the same user to a couple of bugs.
+However, first we'll register a couple of bugs for the Mozilla Firefox
+product:
 
     >>> browser = setupBrowser(auth='Basic test@canonical.com:test')
     >>> browser.open('http://bugs.launchpad.dev/firefox/')
     >>> browser.getLink('Report a bug').click()
     >>> print extract_text(find_main_content(browser.contents))
     Report a bug...
+
     >>> report_bug_url = browser.url
 
     >>> browser.getControl('Summary', index=0).value = 'Test Bug 1'
@@ -197,6 +210,7 @@
     >>> for message in get_feedback_messages(browser.contents):
     ...     print extract_text(message)
     Thank you for your bug report...
+
     >>> bug_1_url = browser.url
 
     >>> browser.open(report_bug_url)
@@ -207,6 +221,7 @@
     >>> for message in get_feedback_messages(browser.contents):
     ...     print extract_text(message)
     Thank you for your bug report...
+
     >>> bug_2_url = browser.url
 
 Next we'll subscribe our user to the first bug we've just registered:
@@ -222,11 +237,11 @@
     ...     print extract_text(message)
     No Privileges Person has been subscribed to this bug...
 
-Now if we repeat our earlier search for bugs our user is subscribed to, we'll
-find our first bug within the results:
+Now if we repeat our earlier search for bugs our user is subscribed to,
+we'll find our first bug within the results:
 
     >>> anon_browser.open(search_url)
-    >>> anon_browser.getControl('Bug subscriber').value = subscriber
+    >>> anon_browser.getControl('Subscriber').value = subscriber
     >>> anon_browser.getControl('Search', index=0).click()
     >>> from lp.bugs.tests.bug import extract_bugtasks
     >>> for bugtask in extract_bugtasks(anon_browser.contents):
@@ -246,13 +261,15 @@
     ...     print extract_text(message)
     No Privileges Person has been subscribed to this bug...
 
-Finally, if we repeat our earlier search for bugs our user is subscribed to,
-we'll find both of our bugs within the results:
+Finally, if we repeat our earlier search for bugs our user is subscribed
+to, we'll find both of our bugs within the results:
 
     >>> anon_browser.open(search_url)
-    >>> anon_browser.getControl('Bug subscriber').value = subscriber
+    >>> anon_browser.getControl('Subscriber').value = subscriber
     >>> anon_browser.getControl('Search', index=0).click()
     >>> for bugtask in extract_bugtasks(anon_browser.contents):
     ...     print 'Task:' + bugtask
     Task:...Test Bug 1...Undecided...New
     Task:...Test Bug 2...Undecided...New
+
+

=== modified file 'lib/lp/bugs/templates/bugtask-macros-tableview.pt'
--- lib/lp/bugs/templates/bugtask-macros-tableview.pt	2011-12-01 14:36:35 +0000
+++ lib/lp/bugs/templates/bugtask-macros-tableview.pt	2011-12-05 16:00:27 +0000
@@ -260,17 +260,16 @@
               <div tal:repeat="widget_value view/getStatusWidgetValues">
                 <tal:checkbox
                     define="widget_id string:status.${widget_value/title}">
-                            <input name="field.status:list"
-                                   type="checkbox"
-                                   tal:attributes="value widget_value/value;
-                                                   checked widget_value/checked;
-                                                   id widget_id"/>
-                            <label style="font-weight: normal"
-                                   tal:content="widget_value/title"
-                                   tal:attributes="for widget_id">
-                              Unconfirmed
-                            </label>
-
+                    <input name="field.status:list"
+                           type="checkbox"
+                           tal:attributes="value widget_value/value;
+                                           checked widget_value/checked;
+                                           id widget_id"/>
+                    <label style="font-weight: normal"
+                           tal:content="widget_value/title"
+                           tal:attributes="for widget_id">
+                      Unconfirmed
+                    </label>
                 </tal:checkbox>
               </div>
             </td>
@@ -279,16 +278,14 @@
               <div tal:repeat="widget_value view/getImportanceWidgetValues">
                 <tal:checkbox
                     define="widget_id string:importance.${widget_value/title}">
-
-                            <input name="field.importance:list"
-                                type="checkbox"
-                                tal:attributes="value widget_value/value;
-                                                checked widget_value/checked;
-                                                id widget_id"/>
-                            <label style="font-weight: normal"
-                                tal:content="widget_value/title"
-                                tal:attributes="for widget_id">Critical</label>
-
+                    <input name="field.importance:list"
+                      type="checkbox"
+                      tal:attributes="value widget_value/value;
+                                      checked widget_value/checked;
+                                      id widget_id"/>
+                    <label style="font-weight: normal"
+                      tal:content="widget_value/title"
+                      tal:attributes="for widget_id">Critical</label>
               </tal:checkbox>
             </div>
           </td>
@@ -297,173 +294,165 @@
     </fieldset>
     <fieldset>
       <legend>People</legend>
-
-          <table>
-            <tr>
-              <td width="40%" tal:condition="view/shouldShowAssigneeWidget">
-                <table>
-                  <tr>
-
-                  <td><label>Assignee:</label></td>
-
-                  </tr>
-                  <tr>
-                    <td>
-
-                    <input
-                        type="radio"
-                        name="assignee_option"
-                        value="any"
-                        id="any"
-                        checked="checked" />
-                      <label style="font-weight: normal"
-                        for="any">Doesn&#8217;t matter</label><br />
-
-                      <input
-                          type="radio"
-                          name="assignee_option"
-                          value="none"
-                          id="none" />
-                        <label style="font-weight: normal"
-                          for="none"> Nobody</label><br />
-                        <div class="field"
-                          tal:define="error
-                          python:view.getFieldError('assignee')">
-                          <div tal:attributes="class python:error and 'error' or None">
-                            <span style="white-space: nowrap">
-                              <input
-                                  type="radio"
-                                  name="assignee_option"
-                                  id="assignee_option"
-                                  value="choose" />
-                              <span
-                                  tal:content="structure view/widgets/assignee"
-                              />
-                            </span>
-                              <div tal:condition="error"
-                                  class="message"
-                                  tal:content="error">An error on
-                                  owner widget
-                              </div>
-                          </div>
-                        </div>
-                    </td>
-                  </tr>
-                </table>
-              </td>
-              <td width="40%">
-                <table>
-
-                  <tal:render-if condition="view/shouldShowReporterWidget">
-                    <tr>
-                      <td>
-                          <label for="field.bug_reporter">Reporter:</label>
-                      </td>
-                    </tr>
-                    <tr>
-                      <td style="white-space: nowrap">
-                        <div class="field"
-                             tal:define="error
-                             python:view.getFieldError('bug_reporter')">
-                          <div tal:attributes=
-                               "class python:error and 'error' or None">
-                            <span tal:content="structure
-                                               view/widgets/bug_reporter"/>
-                            <div tal:condition="error"
-                                 class="message"
-                                 tal:content="error">An error on owner widget
-                            </div>
-                          </div>
-                        </div>
-                      </td>
-                    </tr>
-                  </tal:render-if>
-
-                  <tal:render-if condition="view/shouldShowSupervisorWidget">
-                    <tr>
-                      <td>
-                          <label for="field.bug_supervisor">Bug supervisor:</label>
-                      </td>
-                    </tr>
-                    <tr>
-                      <td style="white-space: nowrap">
-                        <div class="field"
-                             tal:define="error
-                             python:view.getFieldError('bug_supervisor')">
-                          <div tal:attributes=
-                               "class python:error and 'error' or None">
-                            <span tal:content="structure
-                                               view/widgets/bug_supervisor"/>
-                            <div tal:condition="error"
-                                 class="message"
-                                 tal:content="error">An error on owner widget
-                            </div>
-                          </div>
-                        </div>
-                      </td>
-                    </tr>
-                  </tal:render-if>
-
-                  <tal:render-if condition="view/shouldShowCommenterWidget">
-                    <tr>
-                      <td>
-                          <label for="field.bug_commenter">
-                            Bug commenter:
-                          </label>
-                      </td>
-                    </tr>
-                    <tr>
-                      <td style="white-space: nowrap">
-                        <div class="field"
-                             tal:define="error
-                             python:view.getFieldError('bug_commenter')">
-                          <div tal:attributes=
-                               "class python:error and 'error' or None">
-                            <span tal:content="structure
-                                               view/widgets/bug_commenter"/>
-                            <div tal:condition="error"
-                                 class="message"
-                                 tal:content="error">An error on owner widget
-                            </div>
-                          </div>
-                        </div>
-                      </td>
-                    </tr>
-                  </tal:render-if>
-
-                  <tal:render-if condition="view/shouldShowSubscriberWidget">
-                    <tr>
-                      <td>
-                          <label for="field.subscriber">
-                            Bug subscriber:
-                          </label>
-                      </td>
-                    </tr>
-                    <tr>
-                      <td style="white-space: nowrap">
-                        <div class="field"
-                             tal:define="error
-                             python:view.getFieldError('subscriber')">
-                          <div tal:attributes=
-                               "class python:error and 'error' or None">
-                            <span tal:content="structure
-                                               view/widgets/subscriber"/>
-                            <div tal:condition="error"
-                                 class="message"
-                                 tal:content="error">An error on owner widget
-                            </div>
-                          </div>
-                        </div>
-                      </td>
-                    </tr>
-                  </tal:render-if>
-
-                </table>
-              </td>
-              <td>&nbsp;</td>
-            </tr>
-          </table>
-
+        <table>
+          <tr>
+            <td width="40%" tal:condition="view/shouldShowAssigneeWidget">
+              <table>
+                <tr>
+                <td><label>Assignee:</label></td>
+                </tr>
+                <tr>
+                  <td>
+                    <input
+                      type="radio"
+                      name="assignee_option"
+                      value="any"
+                      id="any"
+                      checked="checked" />
+                    <label style="font-weight: normal"
+                      for="any">Doesn&#8217;t matter</label><br />
+                    <input
+                      type="radio"
+                      name="assignee_option"
+                      value="none"
+                      id="none" />
+                    <label style="font-weight: normal"
+                      for="none"> Nobody</label><br />
+                    <div class="field"
+                      tal:define="error
+                      python:view.getFieldError('assignee')">
+                      <div tal:attributes="class python:error and 'error' or None">
+                        <span style="white-space: nowrap">
+                          <input
+                            type="radio"
+                            name="assignee_option"
+                            id="assignee_option"
+                            value="choose" />
+                          <span
+                            tal:content="structure view/widgets/assignee"/>
+                        </span>
+                          <div tal:condition="error"
+                              class="message"
+                              tal:content="error">An error on
+                              owner widget
+                          </div>
+                      </div>
+                    </div>
+                  </td>
+                </tr>
+              </table>
+            </td>
+            <td width="40%">
+              <table>
+                <tal:render-if condition="view/shouldShowReporterWidget">
+                  <tr>
+                    <td>
+                        <label for="field.bug_reporter">Reporter:</label>
+                    </td>
+                  </tr>
+                  <tr>
+                    <td style="white-space: nowrap">
+                      <div class="field"
+                           tal:define="error
+                           python:view.getFieldError('bug_reporter')">
+                        <div tal:attributes="class python:error and 'error' or None">
+                          <span tal:content="structure
+                                             view/widgets/bug_reporter"/>
+                          <div class="message"
+                               tal:condition="error"
+                               tal:content="error">An error on owner widget
+                          </div>
+                        </div>
+                      </div>
+                    </td>
+                  </tr>
+                </tal:render-if>
+
+                <tal:render-if condition="view/shouldShowCommenterWidget">
+                  <tr>
+                    <td>
+                      <label for="field.bug_commenter">
+                        Commenter:
+                      </label>
+                    </td>
+                  </tr>
+                  <tr>
+                    <td style="white-space: nowrap">
+                      <div class="field"
+                           tal:define="error
+                           python:view.getFieldError('bug_commenter')">
+                        <div tal:attributes=
+                             "class python:error and 'error' or None">
+                          <span tal:content="structure
+                                             view/widgets/bug_commenter"/>
+                          <div tal:condition="error"
+                               class="message"
+                               tal:content="error">An error on owner widget
+                          </div>
+                        </div>
+                      </div>
+                    </td>
+                  </tr>
+                </tal:render-if>
+
+                <tal:render-if condition="view/shouldShowSubscriberWidget">
+                  <tr>
+                    <td>
+                      <label for="field.subscriber">
+                        Subscriber:
+                      </label>
+                    </td>
+                  </tr>
+                  <tr>
+                    <td style="white-space: nowrap">
+                      <div class="field"
+                           tal:define="error
+                           python:view.getFieldError('subscriber')">
+                        <div tal:attributes=
+                             "class python:error and 'error' or None">
+                          <span tal:content="structure
+                                             view/widgets/subscriber"/>
+                          <div tal:condition="error"
+                               class="message"
+                               tal:content="error">An error on owner widget
+                          </div>
+                        </div>
+                      </div>
+                    </td>
+                  </tr>
+                </tal:render-if>
+
+                <tal:render-if condition="view/shouldShowStructuralSubscriberWidget">
+                  <tr>
+                    <td>
+                      <label for="field.structural_subscriber"
+                        tal:content="view/structural_subscriber_label" />
+                    </td>
+                  </tr>
+                  <tr>
+                    <td style="white-space: nowrap">
+                      <div class="field"
+                           tal:define="error
+                           python:view.getFieldError('structural_subscriber')">
+                        <div tal:attributes=
+                             "class python:error and 'error' or None">
+                          <span tal:content="structure
+                                             view/widgets/structural_subscriber"/>
+                          <div tal:condition="error"
+                               class="message"
+                               tal:content="error">An error on owner widget
+                          </div>
+                        </div>
+                      </div>
+                    </td>
+                  </tr>
+                </tal:render-if>
+
+              </table>
+            </td>
+            <td>&nbsp;</td>
+          </tr>
+        </table>
     </fieldset>
     <fieldset tal:define="show_component_widget view/shouldShowComponentWidget">
       <legend>Milestones, components, and tags</legend>
@@ -511,62 +500,60 @@
           </td>
         </tr>
 	    <tr>
-              <tal:XXX condition="nothing">
-                # XXX: Bjorn Tillenius 2006-10-02:
-                # The rendering of the widget is pretty much copied from
-                # the widget macro; the difference is that we want to
-                # render the widget in a table, and the label should
-                # be rendered on the same line as the widget. When
-                # FormLayout lands we should be able to use the
-                # standard macro instead.
-              </tal:XXX>
-              <td span="2"
-                tal:define="error view/widgets/tag/error">
-                <div tal:attributes="class python:error and 'error' or ''">
-                  <label tal:attributes="for view/widgets/tag/name"
-                         tal:content="structure view/widgets/tag/label">
-                    Tag
-                  </label>: <input tal:replace="structure view/widgets/tag" />
-                  <a href="/+help-bugs/tag-search.html"
-                     target="help">Tag search help</a>
-                  <div
-                    tal:condition="error"
-                    class="message"
-                    tal:content="structure error"
-                    >An error message.</div>
-                </div>
+        <tal:XXX condition="nothing">
+          # XXX: Bjorn Tillenius 2006-10-02:
+          # The rendering of the widget is pretty much copied from
+          # the widget macro; the difference is that we want to
+          # render the widget in a table, and the label should
+          # be rendered on the same line as the widget. When
+          # FormLayout lands we should be able to use the
+          # standard macro instead.
+        </tal:XXX>
+        <td span="2"
+          tal:define="error view/widgets/tag/error">
+          <div tal:attributes="class python:error and 'error' or ''">
+            <label tal:attributes="for view/widgets/tag/name"
+                   tal:content="structure view/widgets/tag/label">
+              Tag
+            </label>: <input tal:replace="structure view/widgets/tag" />
+            <a href="/+help-bugs/tag-search.html"
+               target="help">Tag search help</a>
+            <div
+              tal:condition="error"
+              class="message"
+              tal:content="structure error"
+              >An error message.</div>
+          </div>
 
-                <div condition="view/shouldShowTagsCombinatorWidget"
-                     class="value">
-                  <label style="font-weight: normal">
-                    <input id="field.tags_combinator.0"
-                           name="field.tags_combinator"
-                           value="ANY" checked="checked"
-                           class="radioType" type="radio" />&nbsp;Any
-                  </label>
-                  <br />
-                  <label style="font-weight: normal">
-                    <input id="field.tags_combinator.1"
-                           name="field.tags_combinator"
-                           value="ALL"
-                           class="radioType" type="radio" />&nbsp;All
-                  </label>
-                </div>
-              </td>
+          <div condition="view/shouldShowTagsCombinatorWidget"
+               class="value">
+            <label style="font-weight: normal">
+              <input id="field.tags_combinator.0"
+                     name="field.tags_combinator"
+                     value="ANY" checked="checked"
+                     class="radioType" type="radio" />&nbsp;Any
+            </label>
+            <br />
+            <label style="font-weight: normal">
+              <input id="field.tags_combinator.1"
+                     name="field.tags_combinator"
+                     value="ALL"
+                     class="radioType" type="radio" />&nbsp;All
+            </label>
+          </div>
+        </td>
 	    </tr>
       </table>
     </fieldset>
 
     <fieldset tal:condition="view/shouldShowUpstreamStatusBox">
       <legend>Upstream status</legend>
-
           <table>
             <tr>
               <td style="white-space: nowrap"
                   tal:content="structure view/widgets/status_upstream" />
             </tr>
           </table>
-
     </fieldset>
 
     <fieldset>
@@ -574,16 +561,16 @@
       <table>
         <tr>
           <td style="white-space: nowrap">
-              <input tal:replace="structure view/widgets/has_cve" />
-              <label style="font-weight: normal"
-                tal:attributes="for view/widgets/has_cve/name">
-                 Show only bugs associated with a CVE
-              </label>
+            <input tal:replace="structure view/widgets/has_cve" />
+            <label style="font-weight: normal"
+              tal:attributes="for view/widgets/has_cve/name">
+               Show only bugs associated with a CVE
+            </label>
           </td>
           <td style="white-space: nowrap">
-              <span tal:content="structure view/widgets/omit_dupes" />
-              <label style="font-weight: normal"
-                for="field.omit_dupes">Hide duplicate bugs</label>
+            <span tal:content="structure view/widgets/omit_dupes" />
+            <label style="font-weight: normal"
+              for="field.omit_dupes">Hide duplicate bugs</label>
           </td>
         </tr>
 
@@ -597,10 +584,10 @@
           </td>
           <td style="white-space: nowrap"
             tal:condition="view/shouldShowNoPackageWidget">
-              <span tal:content="structure view/widgets/has_no_package" />
-              <label style="font-weight: normal" for="field.has_no_package">
-                Hide bugs with packages specified
-              </label>
+            <span tal:content="structure view/widgets/has_no_package" />
+            <label style="font-weight: normal" for="field.has_no_package">
+              Hide bugs with packages specified
+            </label>
           </td>
         </tr>
 

=== modified file 'lib/lp/registry/browser/person.py'
--- lib/lp/registry/browser/person.py	2011-11-25 12:34:41 +0000
+++ lib/lp/registry/browser/person.py	2011-12-02 02:00:10 +0000
@@ -631,7 +631,7 @@
     def softwarebugs(self):
         text = 'Subscribed packages'
         summary = (
-            'A summary report for packages where %s is a bug supervisor.'
+            'A summary report for packages where %s is a subscriber.'
             % self.context.displayname)
         return Link('+packagebugs', text, site='bugs', summary=summary)
 

